# gillespie

Python package for stochastic simulations

## Installation

```bash
pip install gillespie
```

## Usage

See [examples](examples)

## Development

To include/exclude relevant files from source distribution `check-manifest` is needed. Install the dependencies with:

```bash
pip install -e .[dev]
```